
## CATO-CLI - mutation.admin.removeAdmin:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeAdmin) for documentation on this operation.

### Usage for mutation.admin.removeAdmin:

`catocli mutation admin removeAdmin -h`

`catocli mutation admin removeAdmin <accountID> <json>`

`catocli mutation admin removeAdmin 12345 "$(cat < removeAdmin.json)"`

`catocli mutation admin removeAdmin 12345 '{"adminID": "ID"}'`

#### Operation Arguments for mutation.admin.removeAdmin ####
`accountId` [ID] - (required) N/A 
`adminID` [ID] - (required) N/A 
